use std::sync::Arc;

use tokio::sync::Mutex;
use webrtc::{ice_transport::{ice_candidate::RTCIceCandidate, ice_candidate_type::RTCIceCandidateType, ice_server::RTCIceServer}, *};

use lazy_static::lazy_static;

lazy_static! {
    pub static ref MY_ADDRESS: Mutex<String> = Mutex::new(String::new());
}

pub async fn collect_local_address() -> Result<(), Box<dyn std::error::Error>> {
    let SERVER_CONFIG: peer_connection::configuration::RTCConfiguration = peer_connection::configuration::RTCConfiguration {
        ice_servers: vec![RTCIceServer {
            urls: vec!["stun:nhz.jeffthecoder.xyz:3479".to_string()],
            ..Default::default()
        }],
        ..Default::default()
    };
    let api = webrtc::api::APIBuilder::new().build();
    let mut pc = api.new_peer_connection(SERVER_CONFIG.clone()).await?;


    pc.on_ice_candidate(Box::new(|candicate: Option<RTCIceCandidate>|{
        Box::pin(async {
            tracing::info!(?candicate, "on_ice_candidate");
            if let Some(c) = candicate {
                if c.typ == RTCIceCandidateType::Srflx {
                    tracing::info!("+ {}", c.address);
                    let mut address = MY_ADDRESS.lock().await;
                    *address = c.address.clone();
                } else {
                    tracing::info!("  {}", c.address);
                }
            } else {
                tracing::debug!("gather done");
            }
        })
    }));

    let offer = pc.create_offer(None).await?;
    pc.set_local_description(offer).await?;

    let _dc = pc.create_data_channel("some_label", None).await?;

    let mut gather_complete = pc.gathering_complete_promise().await;

    gather_complete.recv().await;

    Ok(())
}
