#[cfg(feature = "embed-templates")]
static TEMPLATES_DIR: include_dir::Dir<'_> = include_dir::include_dir!("$CARGO_MANIFEST_DIR/templates");

pub fn load_templates() -> Result<tera::Tera, Box<dyn std::error::Error>> {
    let mut templates = tera::Tera::parse("templates/**/*.html")?;

    #[cfg(feature = "embed-templates")]
    {
        let template_names: std::collections::HashSet<_> = templates
            .get_template_names()
            .map(|s| s.to_string())
            .collect();
        for entry in TEMPLATES_DIR.find("**/*.html")? {
            tracing::info!(path=entry.path().to_str().unwrap_or_default(), "found embeded template");
            if let Some(file) = entry.as_file() {
                let path = file.path();
                let path = path.to_string_lossy().to_string();
                if let Some(content) = file.contents_utf8() {
                    tracing::info!(path=entry.path().to_str().unwrap_or_default(), "added embeded template");
                    templates.add_raw_template(&path, content)?;
                }
            }
        }
    }

    templates.build_inheritance_chains()?;

    Ok(templates)
}
